Module output

Module output 

Functions

display_entries
Display multiple cron entries
display_entries_with_writer
Display multiple cron entries to a specific writer
display_iterations
Display next N iterations of a cron expression
display_iterations_with_writer
Display next N iterations of a cron expression to a specific writer
display_single
Display a single cron expression
display_single_with_writer
Display a single cron expression to a specific writer